@@ -10,15 +10,14 @@ from datetime import datetime
 
 __config_locales__ = ht.Config.getConfig(parentKey='core', key='locales')
 
-def __createModuleFunctionView__(moduleName, functionName, is_main=False):
+def __createModuleFunctionView__(category, moduleName, functionName, is_main=False):
     try:
         # Creates the JSON config for the view modal form
-        category = ht.getModuleCategory(moduleName)
         functionParams = Utils.getFunctionsParams(category=category, moduleName=moduleName, functionName=functionName)
         
         # Get posible functions with args that uses values from another func
-        funcsFromFunc = None if not hasattr( ht.getModule(moduleName), '_funcArgFromFunc_') else dict(ht.getModule(moduleName).funcArgFromFunc)
-
+        funcsFromFunc = None if not hasattr( ht.getModule(moduleName), '_funcArgFromFunc_') else dict(ht.getModule(moduleName)._funcArgFromFunc_)
+        
         moduleViewConfig = {}
 
         moduleViewConfig['__function__'] = functionName
@@ -55,13 +54,13 @@ def __createModuleFunctionView__(moduleName, functionName, is_main=False):
                         moduleViewConfig[param]['selected'] = moduleViewConfig[param]['value']
             
             # Create the data for auto fill the param with another funcs return
-            if funcsFromFunc and functionName in funcArgFromFunc and len(funcArgFromFunc[functionName]) > 0:
-                for arg in funcArgFromFunc[functionName]:
+            if funcsFromFunc and functionName in funcsFromFunc and len(funcsFromFunc[functionName]) > 0:
+                for arg in funcsFromFunc[functionName]:
                     if arg in moduleViewConfig:
                         if not 'options_from_function' in moduleViewConfig[arg]:
                             moduleViewConfig[arg]['options_from_function'] = {}
-                        for moduleToExecute in funcArgFromFunc[functionName][arg]:
-                            moduleViewConfig[arg]['options_from_function'][moduleToExecute] = funcArgFromFunc[functionName][arg][moduleToExecute]
+                        for moduleToExecute in funcsFromFunc[functionName][arg]:
+                            moduleViewConfig[arg]['options_from_function'][moduleToExecute] = funcsFromFunc[functionName][arg][moduleToExecute]
         else:
             ht.Logger.printMessage(message='No function params', description=functionName, debug_core=True)
 
@@ -80,7 +79,8 @@ def __createModuleFunctionView__(moduleName, functionName, is_main=False):
             moduleViewConfig['submit'] = {}
             moduleViewConfig['submit']['__id__'] = functionName
             moduleViewConfig['submit']['__type__'] = 'submit'
-            moduleViewConfig['submit']['value'] = ' '.join( [ x.capitalize() for x in functionName.split('_') ] )
+            if functionName:
+                moduleViewConfig['submit']['value'] = ' '.join( [ x.capitalize() for x in functionName.split('_') ] )
             moduleViewConfig['submit']['loading_text'] = '{m}ing'.format(m=moduleName.replace('ht_', ''))
 
         Config.__save_django_module_config__(moduleViewConfig, category, moduleName, functionName, is_main=is_main)
@@ -88,7 +88,9 @@ def __createModuleFunctionView__(moduleName, functionName, is_main=False):
         ht.Config.__look_for_changes__()
         ht.Logger.printMessage(message='Creating Function Modal View', description=functionName, debug_core=True)
         return {functionName : moduleViewConfig}
-    except:
+    except Exception as e:
+        Logger.printMessage(str(e), is_error=True)
+        raise
         return None
 
 def __getModulesGuiNames__():
@@ -183,7 +185,10 @@ def __getModulesFunctionsCalls__():
         for func in ht.__modules_loaded__[module]:
             try:
                 for param in ht.__modules_loaded__[module][func]['original_params']:
-                    module_funcs[func] = header.format(header_params=header_params[module][func], module_name=module.split('.')[-1], module_function=func, module_function_params=', '.join(ht.__modules_loaded__[module][func]['original_params'][param]), params=', '.join(header_params_arg[module][func]))
+                    moduleParams = ht.__modules_loaded__[module][func]['original_params'][param]
+                    if not moduleParams:
+                        moduleParams = []
+                    module_funcs[func] = header.format(header_params=header_params[module][func], module_name=module.split('.')[-1], module_function=func, module_function_params=', '.join(moduleParams), params=', '.join(header_params_arg[module][func]))
             except:
                 module_funcs[func] = header.format(header_params=header_params[module][func], module_name=module.split('.')[-1], module_function=func, module_function_params='')
         modulesCalls[module.split('.')[-1]] = module_funcs
@@ -519,8 +524,11 @@ def __createHtmlModalForm__(mod, config_subkey='django_form_main_function', conf
                 
                 elif input_type == 'select':
 
-                    html += "<span class=\"name-select\" value=\"{placeholder}\"></span><select id=\"editable-select-{id}\" name=\"dropdown_{id}\" placeholder=\"{placeholder}\" class=\"{className}\" {required}>".format(placeholder=input_placeholder, className=input_className, id=m, required=required)
-                    html += "<option value='{input_value}' selected></option>".format(input_value=input_value)
+                    html += "<span class=\"name-select\" value=\"{placeholder}\">{placeholder}</span><select id=\"editable-select-{id}\" name=\"{id}\" placeholder=\"{placeholder}\" class=\"{className}\" {required}>".format(placeholder=input_placeholder, className=input_className, id=m, required=required)
+                    html += "<option value='{input_value}' selected>{input_value}</option>".format(input_value=input_value)
+
+                    if input_value in options_from_function:
+                        options_from_function.remove(input_value)
 
                     for func in options_from_function:
                         html += "<option value='{cat}'>{cat}</option>".format(cat=func)
